translate.convert.odf2xliff

Package translate :: Package convert :: Module odf2xliff |
[hide private]
[frames] | no frames]

# Module odf2xliff

source code

convert OpenDocument (ODF) files to XLIFF localization files

Functions | [hide private]
convertodf(inputfile, outputfile, templates, engine) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Imports: factory, contextmanager, with_, odf_io